@@ -99,22 +99,21 @@ ephy_bookmark_set_property (GObject      *object,
       ephy_bookmark_set_url (self, g_value_get_string (value));
       break;
     case PROP_TAGS:
-      g_sequence_free (self->tags);
+      if (self->tags != NULL)
+        g_sequence_free (self->tags);
       self->tags = g_value_get_pointer (value);
-      if (!self->tags)
-        self->tags = g_sequence_new (g_free);
       break;
     case PROP_TYPE:
       g_free (self->type);
-      self->type = g_strdup (g_value_get_string (value));
+      self->type = g_value_dup_string (value);
       break;
     case PROP_PARENT_ID:
       g_free (self->parent_id);
-      self->parent_id = g_strdup (g_value_get_string (value));
+      self->parent_id = g_value_dup_string (value);
       break;
     case PROP_PARENT_NAME:
       g_free (self->parent_name);
-      self->parent_name = g_strdup (g_value_get_string (value));
+      self->parent_name = g_value_dup_string (value);
       break;
     case PROP_LOAD_IN_SIDEBAR:
       self->load_in_sidebar = g_value_get_boolean (value);
@@ -177,7 +176,8 @@ ephy_bookmark_finalize (GObject *object)
   g_free (self->title);
   g_free (self->id);
 
-  g_sequence_free (self->tags);
+  if (self->tags)
+    g_sequence_free (self->tags);
 
   G_OBJECT_CLASS (ephy_bookmark_parent_class)->finalize (object);
 }
@@ -279,7 +279,6 @@ ephy_bookmark_class_init (EphyBookmarkClass *klass)
 static void
 ephy_bookmark_init (EphyBookmark *self)
 {
-  self->tags = g_sequence_new (g_free);
 }
 
 EphyBookmark *
@@ -457,7 +456,6 @@ GSequence *
 ephy_bookmark_get_tags (EphyBookmark *self)
 {
   g_assert (EPHY_IS_BOOKMARK (self));
-  g_assert (self->tags);
 
   return self->tags;
 }
